@@ -80,6 +80,15 @@ def init_args_parser() -> ap.ArgumentParser:
         help='the name of document that is stored in the resulting collection as structure'
     )
 
+    parser.add_argument(
+        '-s',
+        '--section',
+        dest='section',
+        default='Техническое задание',
+        help='the name of the section of the SRS structure, '
+             'relative to which the content will be selected from SRS structure of the document'
+    )
+
     parser.add_argument(
         '-r',
         '--results',
@@ -104,8 +113,11 @@ def main():
     logger.info('the connection to the results collection ("%s") is established', results_coll.name)
 
     if args.results:
-        logger.info('documents in results collection ("%s"):\n%s',
-                    args.results_coll, [structure['document_name'] for structure in results_coll.find({})])
+        logger.info(
+            'documents in results collection ("%s"):\n%s',
+            args.results_coll,
+            [structure['document_name'] for structure in results_coll.find({})]
+        )
         return
 
     mode = args.mode.lower()
@@ -126,7 +138,7 @@ def main():
         document_name = splitext(basename(args.docx_path))[0]
 
         results_coll.insert_one({'document_name': document_name, 'structure': document_structure})
-        logger.info('successful! the created section structure is loaded into the results collection ("%s")',
+        logger.info('the created section structure is loaded into the results collection ("%s")',
                     results_coll.name)
     elif mode == 'keywords':
         results = list(results_coll.find({}))
@@ -135,7 +147,7 @@ def main():
         for idx in range(len(results)):
             if results[idx]['document_name'] == args.docx_name:
                 docx_structure_idx = idx
-                logger.info('the document "%s" was found in the results collection under the sequence number %s!',
+                logger.info('the document "%s" was found in the results collection under the sequence number %s',
                             args.docx_name, docx_structure_idx + 1)
                 break
         if docx_structure_idx < 0:
@@ -144,26 +156,33 @@ def main():
 
         logger.info('initializing SDK pullenti...')
         nlp = NLProcessor(init_pullenti=True)
-        logger.info('OK!')
+        logger.info('done')
 
+        logger.info('parsing section of the document content is "%s"', args.section)
+
+        logger.info('collecting keywords using TF-IDF model...')
         tf_idf_keywords = nlp.get_keywords_tf_idf(
             structures=[result['structure'] for result in results],
-            structure_idx=docx_structure_idx
+            structure_idx=docx_structure_idx,
+            section_name=args.section
         )
-        logger.info('keywords are obtained using the TF-IDF model')
+        logger.info('done')
 
+        logger.info('collecting keywords using pullenti...')
         pullenti_keywords = nlp.get_keywords_pullenti(
-            structure=results[docx_structure_idx]['structure']
+            structure=results[docx_structure_idx]['structure'],
+            section_name=args.section
         )
-        logger.info('keywords are obtained using the pullenti package')
+        logger.info('done')
 
         keywords_table = PrettyTable()
-        keywords_table.add_column('TD-IDF', tf_idf_keywords[:10])
+        keywords_table.add_column('TF-IDF', tf_idf_keywords[:10])
         keywords_table.add_column('Pullenti', pullenti_keywords[:10])
 
-        logger.info('below are the top 10 keywords:\n%s', keywords_table)
+        logger.info('below are the top 10 keywords of the "%s" section of the "%s" document:\n%s',
+                    args.section, args.docx_name, keywords_table)
     else:
-        logger.error('the mode "%s" does not exist!', mode)
+        logger.error('the mode "%s" does not exist', mode)
 
     client.close()
 
