@@ -17,7 +17,15 @@ from srsparser.sections_tree import SectionsTree
 
 
 class NLProcessor:
+    """
+    A class containing natural language processing methods, such as getting keywords, building a TF-IDF model,
+    determining the similarity of strings, and others.
+    """
+
     def __init__(self, init_pullenti: bool):
+        """
+        :param init_pullenti: is it necessary to initialize the pullenti SDK.
+        """
         self.morph = MorphAnalyzer()
 
         if init_pullenti:
@@ -110,9 +118,8 @@ class NLProcessor:
         """
         Builds TF-IDF model for the documents and returns TF-IDF weights.
 
-        If parameter `part_of_speech` is stated,
-        then during text preprocessing all parts of speech, except `part_of_speech`,
-        will be excluded from the documents.
+        If parameter `part_of_speech` is stated, then during text preprocessing all parts of speech,
+        except `part_of_speech`, will be excluded from the documents.
 
         :param documents: text units, for example, a word, phrase, sentence.
         :param part_of_speech: part of speech acronym (see notation for grammem in pymorphy2 package).
@@ -148,12 +155,9 @@ class NLProcessor:
         Builds TF-IDF model for the software requirements specifications (SRS) structures content
         and returns TF-IDF weights.
 
-        If parameter `part_of_speech` is stated, then during text preprocessing all parts of speech,
-        except `part_of_speech`, will be excluded from the structures content.
-
         :param structures: the SRS structure list, which were filled relevant text documents content.
         :param section_name: the name of the section of the SRS structure,
-            relative to which the content will be allocated from each SRS structures.
+            relative to which the content will be selected from each SRS structures.
         :param part_of_speech: part of speech acronym (see notation for grammem in pymorphy2 package).
         :return: TF-IDF weight list for the SRS structures.
         """
@@ -166,14 +170,32 @@ class NLProcessor:
 
         return self.get_tf_idf_weights(documents, part_of_speech)
 
-    def get_keywords_tf_idf(self, structures: List[dict],
-                            structure_idx: int,
-                            section_name='Техническое задание',
-                            part_of_speech='') -> List[str]:
+    def get_keywords_tf_idf(self, structures: List[dict], structure_idx: int,
+                            section_name='Техническое задание', part_of_speech='') -> List[str]:
+        """
+        Returns keywords obtained from analyzing the contents of a structure with index `structure_idx`
+        relative to all transmitted `structures` by constructing a TF-IDF model and obtaining TF-IDF weights.
+
+        :param structures: the SRS structure list, which were filled relevant text documents content.
+        :param structure_idx:
+        :param section_name: the name of the section of the SRS structure,
+            relative to which the content will be selected from each SRS structures.
+        :param part_of_speech: part of speech acronym (see notation for grammem in pymorphy2 package).
+        :return: keyword list.
+        """
         tf_idf_weights = self.get_structures_tf_idf_weights(structures, section_name, part_of_speech)
         return [tf_idf_weight[0] for tf_idf_weight in tf_idf_weights[structure_idx]]
 
     def get_keywords_pullenti(self, structure: dict, section_name='Техническое задание') -> List[str]:
+        """
+        Returns keywords obtained from analyzing the contents of a `structure`
+        by using pullenti package (KeywordAnalyzer).
+
+        :param structure: the SRS structure, which was filled relevant text document content.
+        :param section_name: the name of the section of the SRS structure,
+            relative to which the content will be selected from SRS structure.
+        :return: keyword list.
+        """
         sections_structure = SectionsTree(structure)
         content = sections_structure.get_content(section_name)
 
